@@ -36,10 +36,9 @@ except ImportError:
     from pyspread.lib.dataclasses import dataclass
 import os
 
-try:
-    from pkg_resources import get_distribution, DistributionNotFound
-except ImportError:
-    get_distribution = None
+from importlib.metadata import version as version__
+from importlib.metadata import PackageNotFoundError
+
 from PyQt6.QtCore import QProcess, QSize
 from PyQt6.QtGui import QColor, QTextCursor
 from PyQt6.QtWidgets import (
@@ -73,12 +72,10 @@ class Module:
     def version(self) -> version:
         """Currently installed version number, False if not installed"""
 
-        if get_distribution is None:
-            return
         try:
-            return version.parse(get_distribution(self.name).version)
-        except DistributionNotFound:
-            return False
+            return version.parse(version__(self.name))
+        except PackageNotFoundError:
+            return
 
     def is_installed(self) -> bool:
         """True if the module is installed"""
