@@ -155,6 +155,11 @@ class EditMenu(QMenu):
         self.addSeparator()
         self.addAction(actions.toggle_selection_mode)
         self.addSeparator()
+        self.addAction(actions.shift_cells_down)
+        self.addAction(actions.shift_cells_right)
+        self.addAction(actions.delete_shift_cells_up)
+        self.addAction(actions.delete_shift_cells_left)
+        self.addSeparator()
         self.addAction(actions.insert_rows)
         self.addAction(actions.insert_columns)
         self.addAction(actions.insert_table)
@@ -219,6 +224,8 @@ class FormatMenu(QMenu):
         self.addAction(actions.copy_format)
         self.addAction(actions.paste_format)
         self.addSeparator()
+        self.addAction(actions.default_format)
+        self.addSeparator()
         self.addAction(actions.font)
         self.addAction(actions.bold)
         self.addAction(actions.italics)
@@ -334,7 +341,7 @@ class FileHistoryMenu(QMenu):
 
         self.main_window = parent.parent.main_window
 
-    def update(self):
+    def update_(self):
         """Updates file history menu"""
 
         self.clear()
@@ -451,13 +458,16 @@ class GridContextMenu(QMenu):
         self.addSeparator()
         self.addAction(actions.quote)
         self.addSeparator()
+        self.addAction(actions.shift_cells_down)
+        self.addAction(actions.shift_cells_right)
+        self.addAction(actions.delete_shift_cells_up)
+        self.addAction(actions.delete_shift_cells_left)
+        self.addSeparator()
         self.addAction(actions.insert_rows)
         self.addAction(actions.insert_columns)
-        self.addAction(actions.insert_table)
         self.addSeparator()
         self.addAction(actions.delete_rows)
         self.addAction(actions.delete_columns)
-        self.addAction(actions.delete_table)
 
 
 class HorizontalHeaderContextMenu(QMenu):
